@@ -22,6 +22,7 @@ import octobot_tentacles_manager.api as api
 import octobot_tentacles_manager.configuration as configuration
 import octobot_tentacles_manager.constants as constants
 import octobot_tentacles_manager.util as util
+import octobot_tentacles_manager.managers as managers
 
 
 async def ensure_setup_configuration(tentacle_path=constants.TENTACLES_PATH, bot_path=constants.DEFAULT_BOT_PATH,
@@ -30,6 +31,19 @@ async def ensure_setup_configuration(tentacle_path=constants.TENTACLES_PATH, bot
         await api.repair_installation(tentacle_path, bot_path, bot_install_dir, verbose=False)
 
 
+def refresh_profile_tentacles_setup_config(
+        profile_folder,
+        tentacle_path=constants.TENTACLES_PATH,
+        bot_installation_path=constants.DEFAULT_BOT_PATH,
+        bot_install_dir=constants.DEFAULT_BOT_INSTALL_DIR
+):
+    tentacles_setup_manager = managers.TentaclesSetupManager(path.join(bot_installation_path, tentacle_path),
+                                                             bot_installation_path,
+                                                             path.join(bot_install_dir,
+                                                                       constants.DEFAULT_TENTACLE_CONFIG))
+    tentacles_setup_manager.refresh_profile_tentacles_config(profile_folder)
+
+
 def get_tentacles_setup_config(
         config_path=constants.USER_REFERENCE_TENTACLE_CONFIG_FILE_PATH) -> configuration.TentaclesSetupConfiguration:
     setup_config = configuration.TentaclesSetupConfiguration(config_path=config_path)
@@ -113,6 +127,8 @@ def update_tentacle_config(tentacles_setup_config: configuration.TentaclesSetupC
 
 
 def import_user_tentacles_config_folder(tentacles_setup_config: configuration.TentaclesSetupConfiguration):
+    # WARNING: this code should only be called on profiles that are safe to import (might be a security break otherwise)
+    # => careful with downloaded profiles
     user_tentacles_config_folder = configuration.get_user_tentacles_config_folder(tentacles_setup_config)
     if path.isdir(user_tentacles_config_folder) and user_tentacles_config_folder not in sys.path:
         sys.path.append(user_tentacles_config_folder)
