@@ -22,6 +22,7 @@ import octobot_tentacles_manager.util as util
 
 # tentacle_data_by_tentacle_class is used to cache tentacles metadata
 _tentacle_by_tentacle_class = None
+_tentacle_class_by_class_name = {}
 
 
 def reload_tentacle_by_tentacle_class(tentacles_path=constants.TENTACLES_PATH):
@@ -52,6 +53,14 @@ def get_tentacle_module_path(klass) -> typing.Optional[str]:
     return path.join(tentacle.tentacle_path, tentacle.name) if tentacle else None
 
 
+def get_tentacles_classes_names_from_tentacle_module(tentacle_module_name) -> list:
+    return [
+        tentacle_name
+        for tentacle_name, tentacle_details in _tentacle_by_tentacle_class.items()
+        if tentacle_details.name == tentacle_module_name
+    ]
+
+
 def get_documentation_file_path(klass) -> str:
     return \
         path.join(get_resources_path(klass), f"{klass if isinstance(klass, str) else klass.get_name()}"
@@ -64,3 +73,11 @@ def get_tentacle(klass) -> typing.Optional[models.Tentacle]:
     except (TypeError, AttributeError):
         raise RuntimeError(f"tentacle have not been initialized, call reload_tentacle_data_by_tentacle_class "
                            f"fix this issue")
+
+
+def get_tentacle_class_from_name(tentacle_class_name):
+    return _tentacle_class_by_class_name[tentacle_class_name]
+
+
+def set_tentacle_class_by_name(tentacle_class_name, tentacle_class):
+    _tentacle_class_by_class_name[tentacle_class_name] = tentacle_class
